Kuna exchange API wrapper
=========================


.. image:: https://img.shields.io/pypi/v/kuna.svg
        :target: https://pypi.python.org/pypi/kuna

.. image:: https://travis-ci.org/DmytroLitvinov/kuna.svg?branch=master
        :target: https://travis-ci.org/DmytroLitvinov/kuna

.. image:: https://readthedocs.org/projects/kuna/badge/?version=stable
        :target: https://kuna.readthedocs.io/en/latest/?badge=stable
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/DmytroLitvinov/kuna/shield.svg
     :target: https://pyup.io/repos/github/DmytroLitvinov/kuna/
     :alt: Updates

.. image:: https://pyup.io/repos/github/DmytroLitvinov/kuna/python-3-shield.svg
     :target: https://pyup.io/repos/github/DmytroLitvinov/kuna/
     :alt: Python 3

``kuna`` is a Python package providing access to the `Kuna exchange <https://kuna.io/>`_ server API.
Original documentation of Kuna exchange API here: https://kuna.io/documents/api
